@@ -17,7 +17,7 @@ use CHI::Memoize qw(:all);
 use App::Git::Workflow;
 use App::Git::Workflow::Command qw/get_options/;
 
-our $VERSION  = 1.1.0;
+our $VERSION  = 1.1.1;
 our $workflow = App::Git::Workflow->new;
 our ($name)   = $PROGRAM_NAME =~ m{^.*/(.*?)$}mxs;
 our %option;
@@ -54,7 +54,7 @@ sub run {
         memoize('App::Git::Workflow::commit_details',
             driver     => 'File',
             root_dir   => "$git_dir/.git/gw-commit-detials",
-            expires_in => '1w',
+            expires_in => '1M',
             key        => sub { shift @_; @_ },
         );
         $memoized = 1;
@@ -275,7 +275,7 @@ git-recent - Find what files have been changed recently in a repository
 
 =head1 VERSION
 
-This documentation refers to git-recent version 1.1.0
+This documentation refers to git-recent version 1.1.1
 
 =head1 SYNOPSIS
 
